<div class="mdui-row mdui-row-gapless">
    <div class="mdui-col-xs-3">
        {{ adminList }}
    </div>
    <div class="mdui-col-xs-1"></div>
    <div class="mdui-col-xs-7">
        <div class="mdui-typo-headline">概览</div><br><br>
        <div class="mdui-row mdui-row-gapless">
            <div class="mdui-col-xs-4"><i class="mdui-icon material-icons">language</i> Python{{ pv }}</div>
            <div class="mdui-col-xs-4"><i class="mdui-icon material-icons">settings_applications</i> Flask{{ fv }}</div>
            <div class="mdui-col-xs-4"><i class="mdui-icon material-icons">access_time</i> {{ sv }}</div>
        </div>
        <br><br>
        <div class="mdui-tab" mdui-tab>
            <a href="#post" class="mdui-ripple">最近的帖子</a>
            <a href="#reply" class="mdui-ripple">最近的回复</a>
        </div>
          <div id="post" class="mdui-p-a-2">
            <ul class="mdui-list">
                {% for posts in postlist %}
                <li class="mdui-list-item mdui-ripple">

                    <div class="mdui-list-item-avatar"><img
                            src="{{ get_avater(posts.pusher) }}" />
                    </div>
                    <div class="mdui-list-item-content"><a href="/p/{{ posts.id }}">{{ posts.title }}</a></div>
                    <i class="mdui-list-item-icon mdui-icon material-icons">chat_bubble_outline</i>
                </li>
                {% endfor %}
                {% if postlist == [] or postlist == '' %}
                <br><br>
                <div class="mdui-typo" align="center">
                    <p><strong>这里看起来什么都没有</strong></p>
                </div>
                {% endif %}
            </ul>
          </div>
          <div id="reply" class="mdui-p-a-2">
            <div id="post" class="mdui-p-a-2">
                <ul class="mdui-list">
                    {% for reply in replyList %}
                    <li class="mdui-list-item mdui-ripple">
    
                        <div class="mdui-list-item-avatar"><img
                                src="{{ reply.user.avater }}" />
                        </div>
                        <div class="mdui-list-item-content">{{ reply.reply.body | trim }}</div>
                        <i class="mdui-list-item-icon mdui-icon material-icons">chat_bubble_outline</i>
                    </li>
                    {% endfor %}
                    {% if postlist == [] or postlist == '' %}
                    <br><br>
                    <div class="mdui-typo" align="center">
                        <p><strong>这里看起来什么都没有</strong></p>
                    </div>
                    {% endif %}
                </ul>
              </div>
          </div>

    </div>
</div>