<div class="mdui-container">
    <br><br>
    {% if userObj == '' %}
    <!--Title and describe-->
    <header>
        <div class="mdui-shadow-0 mdui-text-color-theme-icon" align="center">
            <div class="mdui-typo-headline" style="font-weight: 400;">{{ webtitle }}</div><br>
            <div class="mdui-typo-subheading" style="font-weight: 300;">{{ des }}</div>
        </div><br><br><br>
        <div class="mdui-divider"></div><br>
    </header>
    <!--End Title and describe-->
    {% endif %}


    <!-- Start Discuss or RegisterLogin-->
    <div class="mdui-row mdui-row-gapless">
        <div class="mdui-col-xs-2">
            <div class="mdui-col">
                {% if userObj == '' %}
                <button class="mdui-btn mdui-btn-raised mdui-ripple mdui-color-theme-accent">
                    <div mdui-tooltip="{content: '注册/登入'}"  mdui-menu="{target: '#account-op'}"class="mdui-text-color-white" style="font-weight:700;"> 注册/登入</div>
                </button>
                {% else %}
                <button class="mdui-btn mdui-btn-raised mdui-ripple mdui-color-theme-accent">
                    <div class="mdui-text-color-white" style="font-weight:700;"><a class="mdui-text-color-white" href="/write"> 开始一个新的讨论 </a></div>
                </button>
                {% endif %}
                <br>
                <br>
                <ul class="mdui-list mdui-list-dense">
                    <li class="mdui-list-item mdui-ripple">
                        <i class="mdui-list-item-icon mdui-icon material-icons">chat</i>
                        <div class="mdui-list-item-content"><a href="/">所有讨论</a></div>
                    </li>
                    {% if not userObj == '' %}
                    <li class="mdui-list-item mdui-ripple">
                        <i class="mdui-list-item-icon mdui-icon material-icons">stars</i>
                        <div class="mdui-list-item-content"><a href="/relation">参与的</a></div>
                    </li>
                    <li class="mdui-list-item mdui-ripple">
                        <i class="mdui-list-item-icon mdui-icon material-icons">notifications</i>
                        <div class="mdui-list-item-content"><a href="/notifications">通知</a></div>
                    </li>
                    {% endif %}
                    <li class="mdui-divider"></li>
                    {% for i in tagslist %}
                    <li class="mdui-list-item mdui-ripple">
                        <i class="mdui-list-item-icon mdui-icon material-icons">{{ i.icon }}</i>
                        <div class="mdui-list-item-content"><a href="/t/{{ i.id }}">{{ i.name }}</a></div>
                    </li>
                    {% endfor %}

                </ul>




            </div>

        </div>
        <div class="mdui-col-xs-10">
            <ul class="mdui-list">
                {% for post in postlist %}
                <li class="mdui-list-item mdui-ripple">

                    <div class="mdui-list-item-avatar"><img
                            src="{{ get_avater(post.pusher) }}" />
                    </div>
                    <div class="mdui-list-item-content"><a href="/p/{{ post.id }}">{{ post.title }}</a></div>
                    <i class="mdui-list-item-icon mdui-icon material-icons">chat_bubble_outline</i>
                </li>
                {% endfor %}
                {% if postlist == [] or postlist == '' %}
                <br><br><br><br><br><br><br>
                <div class="mdui-typo" align="center">
                    <p><strong>这里看起来什么都没有</strong></p>
                </div>
                {% endif %}
            </ul>
        </div>
    </div>
</div>